@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
-from django.test import TestCase
-from models import User
 from datetime import datetime
 
+from django.test import TestCase
+
+from .models import User
+
 USER_ID = '4'
 USER_USERNAME = 'zuck'
 
+
 class FacebookUsersTest(TestCase):
 
     def test_fetch_user(self):
@@ -21,9 +24,9 @@ class FacebookUsersTest(TestCase):
         self.assertEqual(user.name, u'Mark Zuckerberg')
         self.assertEqual(user.first_name, 'Mark')
         self.assertEqual(user.last_name, 'Zuckerberg')
-        self.assertEqual(user.link, 'http://www.facebook.com/zuck')
+        self.assertEqual(user.link, 'https://www.facebook.com/zuck')
         self.assertEqual(user.username, USER_USERNAME)
         self.assertEqual(user.gender, 'male')
         self.assertEqual(user.locale, 'en_US')
         self.assertTrue(isinstance(user.cover, dict))
-        self.assertTrue(isinstance(user.updated_time, datetime))
\ No newline at end of file
+        self.assertTrue(isinstance(user.updated_time, datetime))
